elixir-remote-monitor v1.0.0 Mix.Tasks.RemoteMonitor

Summary

Functions

A task needs to implement run which receives a list of command line args

Functions

observe!(conn, remote_host, erlang_cookie)
run(args)

A task needs to implement run which receives a list of command line args.

Callback implementation for Mix.Task.run/1.